# Guid for Housing-Project

## Cloning the Repository
To clone the repository, you will need to have git installed on your machine. You can check if git is installed by running the command git --version in your terminal. If git is not installed, you can download it from the official website.

Once git is installed, you can clone the repository by running the following command:

```
git clone https://github.com/pavanbongu7/mle-training-mlflow>.git
```
## Setting up the Environment
To set up the environment, you will need to have conda installed on your machine. You can check if conda is installed by running the command conda --version in your terminal. If conda is not installed, you can download it from the official website.

Once conda is installed, you can create the environment by running the following command:
```
conda env create -f env.yml
```
This command will create an environment based on the specifications in the env.yml file.

To activate the environment, run the following command:
```
conda activate mle-dev
```
## Installing the Package
To install the package, you can use the following command:
```
pip install .
pip install housing_package
```